# Generated by Django 3.2.2 on 2021-05-15 20:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('product', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='product',
            name='price_with_tax',
            field=models.IntegerField(default=1),
            preserve_default=False,
        ),
    ]
