# Generated by Django 3.2.3 on 2021-05-17 19:12

from django.db import migrations, models
import valuta.contrib.django_integration.models


class Migration(migrations.Migration):

    dependencies = [
        ('product', '0002_product_price_with_tax'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProductProxyCastToDecimal',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('price', models.IntegerField()),
                ('price_with_tax', models.IntegerField()),
                ('currency', valuta.contrib.django_integration.models.CurrencyField(choices=[('AFN', 'Afghan Afghani'), ('ALL', 'Albanian Lek'), ('DZD', 'Algerian Dinar'), ('AOA', 'Angolan Kwanza'), ('ARS', 'Argentine Peso'), ('AMD', 'Armenian Dram'), ('AWG', 'Aruban Florin'), ('AUD', 'Australian Dollar'), ('AZN', 'Azerbaijani Manat'), ('BSD', 'Bahamian Dollar'), ('BHD', 'Bahraini Dinar'), ('BDT', 'Bangladeshi Taka'), ('BBD', 'Barbadian Dollar'), ('BYN', 'Belarusian Ruble'), ('BZD', 'Belize Dollar'), ('BMD', 'Bermudan Dollar'), ('BTN', 'Bhutanese Ngultrum'), ('BTC', 'Bitcoin'), ('BOB', 'Bolivian Boliviano'), ('BAM', 'Bosnia-Herzegovina Convertible Mark'), ('BWP', 'Botswanan Pula'), ('BRL', 'Brazilian Real'), ('GBP', 'British Pound'), ('BND', 'Brunei Dollar'), ('BGN', 'Bulgarian Lev'), ('BIF', 'Burundian Franc'), ('XPF', 'CFP Franc'), ('CKD', 'CKD'), ('KHR', 'Cambodian Riel'), ('CAD', 'Canadian Dollar'), ('CVE', 'Cape Verdean Escudo'), ('KYD', 'Cayman Islands Dollar'), ('XAF', 'Central African CFA Franc'), ('CLP', 'Chilean Peso'), ('CNY', 'Chinese Yuan'), ('COP', 'Colombian Peso'), ('KMF', 'Comorian Franc'), ('CDF', 'Congolese Franc'), ('CRC', 'Costa Rican Colón'), ('HRK', 'Croatian Kuna'), ('CUP', 'Cuban Peso'), ('CZK', 'Czech Koruna'), ('DKK', 'Danish Krone'), ('DJF', 'Djiboutian Franc'), ('DOP', 'Dominican Peso'), ('XCD', 'East Caribbean Dollar'), ('EGP', 'Egyptian Pound'), ('ERN', 'Eritrean Nakfa'), ('ETB', 'Ethiopian Birr'), ('EUR', 'Euro'), ('FOK', 'FOK'), ('FKP', 'Falkland Islands Pound'), ('FJD', 'Fijian Dollar'), ('GGP', 'GGP'), ('GMD', 'Gambian Dalasi'), ('GEL', 'Georgian Lari'), ('GHS', 'Ghanaian Cedi'), ('GIP', 'Gibraltar Pound'), ('GTQ', 'Guatemalan Quetzal'), ('GNF', 'Guinean Franc'), ('GYD', 'Guyanaese Dollar'), ('HTG', 'Haitian Gourde'), ('HNL', 'Honduran Lempira'), ('HKD', 'Hong Kong Dollar'), ('HUF', 'Hungarian Forint'), ('IMP', 'IMP'), ('ISK', 'Icelandic Króna'), ('INR', 'Indian Rupee'), ('IDR', 'Indonesian Rupiah'), ('IRR', 'Iranian Rial'), ('IQD', 'Iraqi Dinar'), ('ILS', 'Israeli New Shekel'), ('JEP', 'JEP'), ('JMD', 'Jamaican Dollar'), ('JPY', 'Japanese Yen'), ('JOD', 'Jordanian Dinar'), ('KID', 'KID'), ('KZT', 'Kazakhstani Tenge'), ('KES', 'Kenyan Shilling'), ('KWD', 'Kuwaiti Dinar'), ('KGS', 'Kyrgystani Som'), ('LAK', 'Laotian Kip'), ('LBP', 'Lebanese Pound'), ('LSL', 'Lesotho Loti'), ('LRD', 'Liberian Dollar'), ('LYD', 'Libyan Dinar'), ('MOP', 'Macanese Pataca'), ('MKD', 'Macedonian Denar'), ('MGA', 'Malagasy Ariary'), ('MWK', 'Malawian Kwacha'), ('MYR', 'Malaysian Ringgit'), ('MVR', 'Maldivian Rufiyaa'), ('MRU', 'Mauritanian Ouguiya'), ('MUR', 'Mauritian Rupee'), ('MXN', 'Mexican Peso'), ('MDL', 'Moldovan Leu'), ('MNT', 'Mongolian Tugrik'), ('MAD', 'Moroccan Dirham'), ('MZN', 'Mozambican Metical'), ('MMK', 'Myanmar Kyat'), ('NAD', 'Namibian Dollar'), ('NPR', 'Nepalese Rupee'), ('ANG', 'Netherlands Antillean Guilder'), ('TWD', 'New Taiwan Dollar'), ('NZD', 'New Zealand Dollar'), ('NIO', 'Nicaraguan Córdoba'), ('NGN', 'Nigerian Naira'), ('KPW', 'North Korean Won'), ('NOK', 'Norwegian Krone'), ('OMR', 'Omani Rial'), ('PND', 'PND'), ('PRB', 'PRB'), ('PKR', 'Pakistani Rupee'), ('PAB', 'Panamanian Balboa'), ('PGK', 'Papua New Guinean Kina'), ('PYG', 'Paraguayan Guarani'), ('PEN', 'Peruvian Sol'), ('PHP', 'Philippine Piso'), ('PLN', 'Polish Zloty'), ('QAR', 'Qatari Rial'), ('RON', 'Romanian Leu'), ('RUB', 'Russian Ruble'), ('RWF', 'Rwandan Franc'), ('SLS', 'SLS'), ('WST', 'Samoan Tala'), ('SAR', 'Saudi Riyal'), ('RSD', 'Serbian Dinar'), ('SCR', 'Seychellois Rupee'), ('SLL', 'Sierra Leonean Leone'), ('SGD', 'Singapore Dollar'), ('SBD', 'Solomon Islands Dollar'), ('SOS', 'Somali Shilling'), ('ZAR', 'South African Rand'), ('KRW', 'South Korean Won'), ('SSP', 'South Sudanese Pound'), ('LKR', 'Sri Lankan Rupee'), ('SHP', 'St. Helena Pound'), ('SDG', 'Sudanese Pound'), ('SRD', 'Surinamese Dollar'), ('SZL', 'Swazi Lilangeni'), ('SEK', 'Swedish Krona'), ('CHF', 'Swiss Franc'), ('SYP', 'Syrian Pound'), ('STN', 'São Tomé & Príncipe Dobra'), ('TVD', 'TVD'), ('TJS', 'Tajikistani Somoni'), ('TZS', 'Tanzanian Shilling'), ('THB', 'Thai Baht'), ('TOP', 'Tongan Paʻanga'), ('TTD', 'Trinidad & Tobago Dollar'), ('TND', 'Tunisian Dinar'), ('TRY', 'Turkish Lira'), ('TMT', 'Turkmenistani Manat'), ('USD', 'US Dollar'), ('UGX', 'Ugandan Shilling'), ('UAH', 'Ukrainian Hryvnia'), ('AED', 'United Arab Emirates Dirham'), ('UYU', 'Uruguayan Peso'), ('UZS', 'Uzbekistani Som'), ('VUV', 'Vanuatu Vatu'), ('VES', 'Venezuelan Bolívar'), ('VND', 'Vietnamese Dong'), ('XOF', 'West African CFA Franc'), ('YER', 'Yemeni Rial'), ('ZWB', 'ZWB'), ('ZMW', 'Zambian Kwacha')], max_length=10)),
            ],
            options={
                'verbose_name': 'Product proxy (cast_to=decimal)',
                'verbose_name_plural': 'Product proxies (cast_to=decimal)',
                'db_table': 'product_product',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='ProductProxyCastToFloat',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('price', models.IntegerField()),
                ('price_with_tax', models.IntegerField()),
                ('currency', valuta.contrib.django_integration.models.CurrencyField(choices=[('AFN', 'Afghan Afghani'), ('ALL', 'Albanian Lek'), ('DZD', 'Algerian Dinar'), ('AOA', 'Angolan Kwanza'), ('ARS', 'Argentine Peso'), ('AMD', 'Armenian Dram'), ('AWG', 'Aruban Florin'), ('AUD', 'Australian Dollar'), ('AZN', 'Azerbaijani Manat'), ('BSD', 'Bahamian Dollar'), ('BHD', 'Bahraini Dinar'), ('BDT', 'Bangladeshi Taka'), ('BBD', 'Barbadian Dollar'), ('BYN', 'Belarusian Ruble'), ('BZD', 'Belize Dollar'), ('BMD', 'Bermudan Dollar'), ('BTN', 'Bhutanese Ngultrum'), ('BTC', 'Bitcoin'), ('BOB', 'Bolivian Boliviano'), ('BAM', 'Bosnia-Herzegovina Convertible Mark'), ('BWP', 'Botswanan Pula'), ('BRL', 'Brazilian Real'), ('GBP', 'British Pound'), ('BND', 'Brunei Dollar'), ('BGN', 'Bulgarian Lev'), ('BIF', 'Burundian Franc'), ('XPF', 'CFP Franc'), ('CKD', 'CKD'), ('KHR', 'Cambodian Riel'), ('CAD', 'Canadian Dollar'), ('CVE', 'Cape Verdean Escudo'), ('KYD', 'Cayman Islands Dollar'), ('XAF', 'Central African CFA Franc'), ('CLP', 'Chilean Peso'), ('CNY', 'Chinese Yuan'), ('COP', 'Colombian Peso'), ('KMF', 'Comorian Franc'), ('CDF', 'Congolese Franc'), ('CRC', 'Costa Rican Colón'), ('HRK', 'Croatian Kuna'), ('CUP', 'Cuban Peso'), ('CZK', 'Czech Koruna'), ('DKK', 'Danish Krone'), ('DJF', 'Djiboutian Franc'), ('DOP', 'Dominican Peso'), ('XCD', 'East Caribbean Dollar'), ('EGP', 'Egyptian Pound'), ('ERN', 'Eritrean Nakfa'), ('ETB', 'Ethiopian Birr'), ('EUR', 'Euro'), ('FOK', 'FOK'), ('FKP', 'Falkland Islands Pound'), ('FJD', 'Fijian Dollar'), ('GGP', 'GGP'), ('GMD', 'Gambian Dalasi'), ('GEL', 'Georgian Lari'), ('GHS', 'Ghanaian Cedi'), ('GIP', 'Gibraltar Pound'), ('GTQ', 'Guatemalan Quetzal'), ('GNF', 'Guinean Franc'), ('GYD', 'Guyanaese Dollar'), ('HTG', 'Haitian Gourde'), ('HNL', 'Honduran Lempira'), ('HKD', 'Hong Kong Dollar'), ('HUF', 'Hungarian Forint'), ('IMP', 'IMP'), ('ISK', 'Icelandic Króna'), ('INR', 'Indian Rupee'), ('IDR', 'Indonesian Rupiah'), ('IRR', 'Iranian Rial'), ('IQD', 'Iraqi Dinar'), ('ILS', 'Israeli New Shekel'), ('JEP', 'JEP'), ('JMD', 'Jamaican Dollar'), ('JPY', 'Japanese Yen'), ('JOD', 'Jordanian Dinar'), ('KID', 'KID'), ('KZT', 'Kazakhstani Tenge'), ('KES', 'Kenyan Shilling'), ('KWD', 'Kuwaiti Dinar'), ('KGS', 'Kyrgystani Som'), ('LAK', 'Laotian Kip'), ('LBP', 'Lebanese Pound'), ('LSL', 'Lesotho Loti'), ('LRD', 'Liberian Dollar'), ('LYD', 'Libyan Dinar'), ('MOP', 'Macanese Pataca'), ('MKD', 'Macedonian Denar'), ('MGA', 'Malagasy Ariary'), ('MWK', 'Malawian Kwacha'), ('MYR', 'Malaysian Ringgit'), ('MVR', 'Maldivian Rufiyaa'), ('MRU', 'Mauritanian Ouguiya'), ('MUR', 'Mauritian Rupee'), ('MXN', 'Mexican Peso'), ('MDL', 'Moldovan Leu'), ('MNT', 'Mongolian Tugrik'), ('MAD', 'Moroccan Dirham'), ('MZN', 'Mozambican Metical'), ('MMK', 'Myanmar Kyat'), ('NAD', 'Namibian Dollar'), ('NPR', 'Nepalese Rupee'), ('ANG', 'Netherlands Antillean Guilder'), ('TWD', 'New Taiwan Dollar'), ('NZD', 'New Zealand Dollar'), ('NIO', 'Nicaraguan Córdoba'), ('NGN', 'Nigerian Naira'), ('KPW', 'North Korean Won'), ('NOK', 'Norwegian Krone'), ('OMR', 'Omani Rial'), ('PND', 'PND'), ('PRB', 'PRB'), ('PKR', 'Pakistani Rupee'), ('PAB', 'Panamanian Balboa'), ('PGK', 'Papua New Guinean Kina'), ('PYG', 'Paraguayan Guarani'), ('PEN', 'Peruvian Sol'), ('PHP', 'Philippine Piso'), ('PLN', 'Polish Zloty'), ('QAR', 'Qatari Rial'), ('RON', 'Romanian Leu'), ('RUB', 'Russian Ruble'), ('RWF', 'Rwandan Franc'), ('SLS', 'SLS'), ('WST', 'Samoan Tala'), ('SAR', 'Saudi Riyal'), ('RSD', 'Serbian Dinar'), ('SCR', 'Seychellois Rupee'), ('SLL', 'Sierra Leonean Leone'), ('SGD', 'Singapore Dollar'), ('SBD', 'Solomon Islands Dollar'), ('SOS', 'Somali Shilling'), ('ZAR', 'South African Rand'), ('KRW', 'South Korean Won'), ('SSP', 'South Sudanese Pound'), ('LKR', 'Sri Lankan Rupee'), ('SHP', 'St. Helena Pound'), ('SDG', 'Sudanese Pound'), ('SRD', 'Surinamese Dollar'), ('SZL', 'Swazi Lilangeni'), ('SEK', 'Swedish Krona'), ('CHF', 'Swiss Franc'), ('SYP', 'Syrian Pound'), ('STN', 'São Tomé & Príncipe Dobra'), ('TVD', 'TVD'), ('TJS', 'Tajikistani Somoni'), ('TZS', 'Tanzanian Shilling'), ('THB', 'Thai Baht'), ('TOP', 'Tongan Paʻanga'), ('TTD', 'Trinidad & Tobago Dollar'), ('TND', 'Tunisian Dinar'), ('TRY', 'Turkish Lira'), ('TMT', 'Turkmenistani Manat'), ('USD', 'US Dollar'), ('UGX', 'Ugandan Shilling'), ('UAH', 'Ukrainian Hryvnia'), ('AED', 'United Arab Emirates Dirham'), ('UYU', 'Uruguayan Peso'), ('UZS', 'Uzbekistani Som'), ('VUV', 'Vanuatu Vatu'), ('VES', 'Venezuelan Bolívar'), ('VND', 'Vietnamese Dong'), ('XOF', 'West African CFA Franc'), ('YER', 'Yemeni Rial'), ('ZWB', 'ZWB'), ('ZMW', 'Zambian Kwacha')], max_length=10)),
            ],
            options={
                'verbose_name': 'Product proxy (cast_to=float)',
                'verbose_name_plural': 'Product proxies (cast_to=float)',
                'db_table': 'product_product',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='ProductProxyCastToInt',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('price', models.IntegerField()),
                ('price_with_tax', models.IntegerField()),
                ('currency', valuta.contrib.django_integration.models.CurrencyField(choices=[('AFN', 'Afghan Afghani'), ('ALL', 'Albanian Lek'), ('DZD', 'Algerian Dinar'), ('AOA', 'Angolan Kwanza'), ('ARS', 'Argentine Peso'), ('AMD', 'Armenian Dram'), ('AWG', 'Aruban Florin'), ('AUD', 'Australian Dollar'), ('AZN', 'Azerbaijani Manat'), ('BSD', 'Bahamian Dollar'), ('BHD', 'Bahraini Dinar'), ('BDT', 'Bangladeshi Taka'), ('BBD', 'Barbadian Dollar'), ('BYN', 'Belarusian Ruble'), ('BZD', 'Belize Dollar'), ('BMD', 'Bermudan Dollar'), ('BTN', 'Bhutanese Ngultrum'), ('BTC', 'Bitcoin'), ('BOB', 'Bolivian Boliviano'), ('BAM', 'Bosnia-Herzegovina Convertible Mark'), ('BWP', 'Botswanan Pula'), ('BRL', 'Brazilian Real'), ('GBP', 'British Pound'), ('BND', 'Brunei Dollar'), ('BGN', 'Bulgarian Lev'), ('BIF', 'Burundian Franc'), ('XPF', 'CFP Franc'), ('CKD', 'CKD'), ('KHR', 'Cambodian Riel'), ('CAD', 'Canadian Dollar'), ('CVE', 'Cape Verdean Escudo'), ('KYD', 'Cayman Islands Dollar'), ('XAF', 'Central African CFA Franc'), ('CLP', 'Chilean Peso'), ('CNY', 'Chinese Yuan'), ('COP', 'Colombian Peso'), ('KMF', 'Comorian Franc'), ('CDF', 'Congolese Franc'), ('CRC', 'Costa Rican Colón'), ('HRK', 'Croatian Kuna'), ('CUP', 'Cuban Peso'), ('CZK', 'Czech Koruna'), ('DKK', 'Danish Krone'), ('DJF', 'Djiboutian Franc'), ('DOP', 'Dominican Peso'), ('XCD', 'East Caribbean Dollar'), ('EGP', 'Egyptian Pound'), ('ERN', 'Eritrean Nakfa'), ('ETB', 'Ethiopian Birr'), ('EUR', 'Euro'), ('FOK', 'FOK'), ('FKP', 'Falkland Islands Pound'), ('FJD', 'Fijian Dollar'), ('GGP', 'GGP'), ('GMD', 'Gambian Dalasi'), ('GEL', 'Georgian Lari'), ('GHS', 'Ghanaian Cedi'), ('GIP', 'Gibraltar Pound'), ('GTQ', 'Guatemalan Quetzal'), ('GNF', 'Guinean Franc'), ('GYD', 'Guyanaese Dollar'), ('HTG', 'Haitian Gourde'), ('HNL', 'Honduran Lempira'), ('HKD', 'Hong Kong Dollar'), ('HUF', 'Hungarian Forint'), ('IMP', 'IMP'), ('ISK', 'Icelandic Króna'), ('INR', 'Indian Rupee'), ('IDR', 'Indonesian Rupiah'), ('IRR', 'Iranian Rial'), ('IQD', 'Iraqi Dinar'), ('ILS', 'Israeli New Shekel'), ('JEP', 'JEP'), ('JMD', 'Jamaican Dollar'), ('JPY', 'Japanese Yen'), ('JOD', 'Jordanian Dinar'), ('KID', 'KID'), ('KZT', 'Kazakhstani Tenge'), ('KES', 'Kenyan Shilling'), ('KWD', 'Kuwaiti Dinar'), ('KGS', 'Kyrgystani Som'), ('LAK', 'Laotian Kip'), ('LBP', 'Lebanese Pound'), ('LSL', 'Lesotho Loti'), ('LRD', 'Liberian Dollar'), ('LYD', 'Libyan Dinar'), ('MOP', 'Macanese Pataca'), ('MKD', 'Macedonian Denar'), ('MGA', 'Malagasy Ariary'), ('MWK', 'Malawian Kwacha'), ('MYR', 'Malaysian Ringgit'), ('MVR', 'Maldivian Rufiyaa'), ('MRU', 'Mauritanian Ouguiya'), ('MUR', 'Mauritian Rupee'), ('MXN', 'Mexican Peso'), ('MDL', 'Moldovan Leu'), ('MNT', 'Mongolian Tugrik'), ('MAD', 'Moroccan Dirham'), ('MZN', 'Mozambican Metical'), ('MMK', 'Myanmar Kyat'), ('NAD', 'Namibian Dollar'), ('NPR', 'Nepalese Rupee'), ('ANG', 'Netherlands Antillean Guilder'), ('TWD', 'New Taiwan Dollar'), ('NZD', 'New Zealand Dollar'), ('NIO', 'Nicaraguan Córdoba'), ('NGN', 'Nigerian Naira'), ('KPW', 'North Korean Won'), ('NOK', 'Norwegian Krone'), ('OMR', 'Omani Rial'), ('PND', 'PND'), ('PRB', 'PRB'), ('PKR', 'Pakistani Rupee'), ('PAB', 'Panamanian Balboa'), ('PGK', 'Papua New Guinean Kina'), ('PYG', 'Paraguayan Guarani'), ('PEN', 'Peruvian Sol'), ('PHP', 'Philippine Piso'), ('PLN', 'Polish Zloty'), ('QAR', 'Qatari Rial'), ('RON', 'Romanian Leu'), ('RUB', 'Russian Ruble'), ('RWF', 'Rwandan Franc'), ('SLS', 'SLS'), ('WST', 'Samoan Tala'), ('SAR', 'Saudi Riyal'), ('RSD', 'Serbian Dinar'), ('SCR', 'Seychellois Rupee'), ('SLL', 'Sierra Leonean Leone'), ('SGD', 'Singapore Dollar'), ('SBD', 'Solomon Islands Dollar'), ('SOS', 'Somali Shilling'), ('ZAR', 'South African Rand'), ('KRW', 'South Korean Won'), ('SSP', 'South Sudanese Pound'), ('LKR', 'Sri Lankan Rupee'), ('SHP', 'St. Helena Pound'), ('SDG', 'Sudanese Pound'), ('SRD', 'Surinamese Dollar'), ('SZL', 'Swazi Lilangeni'), ('SEK', 'Swedish Krona'), ('CHF', 'Swiss Franc'), ('SYP', 'Syrian Pound'), ('STN', 'São Tomé & Príncipe Dobra'), ('TVD', 'TVD'), ('TJS', 'Tajikistani Somoni'), ('TZS', 'Tanzanian Shilling'), ('THB', 'Thai Baht'), ('TOP', 'Tongan Paʻanga'), ('TTD', 'Trinidad & Tobago Dollar'), ('TND', 'Tunisian Dinar'), ('TRY', 'Turkish Lira'), ('TMT', 'Turkmenistani Manat'), ('USD', 'US Dollar'), ('UGX', 'Ugandan Shilling'), ('UAH', 'Ukrainian Hryvnia'), ('AED', 'United Arab Emirates Dirham'), ('UYU', 'Uruguayan Peso'), ('UZS', 'Uzbekistani Som'), ('VUV', 'Vanuatu Vatu'), ('VES', 'Venezuelan Bolívar'), ('VND', 'Vietnamese Dong'), ('XOF', 'West African CFA Franc'), ('YER', 'Yemeni Rial'), ('ZWB', 'ZWB'), ('ZMW', 'Zambian Kwacha')], max_length=10)),
            ],
            options={
                'verbose_name': 'Product proxy (cast_to=int)',
                'verbose_name_plural': 'Product proxies (cast_to=int)',
                'db_table': 'product_product',
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='ProductProxyLimitChoicesTo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('price', models.IntegerField()),
                ('price_with_tax', models.IntegerField()),
                ('currency', valuta.contrib.django_integration.models.CurrencyField(choices=[('AFN', 'Afghan Afghani'), ('ALL', 'Albanian Lek'), ('DZD', 'Algerian Dinar'), ('AOA', 'Angolan Kwanza'), ('ARS', 'Argentine Peso'), ('AMD', 'Armenian Dram'), ('AWG', 'Aruban Florin'), ('AUD', 'Australian Dollar'), ('AZN', 'Azerbaijani Manat'), ('BSD', 'Bahamian Dollar'), ('BHD', 'Bahraini Dinar'), ('BDT', 'Bangladeshi Taka'), ('BBD', 'Barbadian Dollar'), ('BYN', 'Belarusian Ruble'), ('BZD', 'Belize Dollar'), ('BMD', 'Bermudan Dollar'), ('BTN', 'Bhutanese Ngultrum'), ('BTC', 'Bitcoin'), ('BOB', 'Bolivian Boliviano'), ('BAM', 'Bosnia-Herzegovina Convertible Mark'), ('BWP', 'Botswanan Pula'), ('BRL', 'Brazilian Real'), ('GBP', 'British Pound'), ('BND', 'Brunei Dollar'), ('BGN', 'Bulgarian Lev'), ('BIF', 'Burundian Franc'), ('XPF', 'CFP Franc'), ('CKD', 'CKD'), ('KHR', 'Cambodian Riel'), ('CAD', 'Canadian Dollar'), ('CVE', 'Cape Verdean Escudo'), ('KYD', 'Cayman Islands Dollar'), ('XAF', 'Central African CFA Franc'), ('CLP', 'Chilean Peso'), ('CNY', 'Chinese Yuan'), ('COP', 'Colombian Peso'), ('KMF', 'Comorian Franc'), ('CDF', 'Congolese Franc'), ('CRC', 'Costa Rican Colón'), ('HRK', 'Croatian Kuna'), ('CUP', 'Cuban Peso'), ('CZK', 'Czech Koruna'), ('DKK', 'Danish Krone'), ('DJF', 'Djiboutian Franc'), ('DOP', 'Dominican Peso'), ('XCD', 'East Caribbean Dollar'), ('EGP', 'Egyptian Pound'), ('ERN', 'Eritrean Nakfa'), ('ETB', 'Ethiopian Birr'), ('EUR', 'Euro'), ('FOK', 'FOK'), ('FKP', 'Falkland Islands Pound'), ('FJD', 'Fijian Dollar'), ('GGP', 'GGP'), ('GMD', 'Gambian Dalasi'), ('GEL', 'Georgian Lari'), ('GHS', 'Ghanaian Cedi'), ('GIP', 'Gibraltar Pound'), ('GTQ', 'Guatemalan Quetzal'), ('GNF', 'Guinean Franc'), ('GYD', 'Guyanaese Dollar'), ('HTG', 'Haitian Gourde'), ('HNL', 'Honduran Lempira'), ('HKD', 'Hong Kong Dollar'), ('HUF', 'Hungarian Forint'), ('IMP', 'IMP'), ('ISK', 'Icelandic Króna'), ('INR', 'Indian Rupee'), ('IDR', 'Indonesian Rupiah'), ('IRR', 'Iranian Rial'), ('IQD', 'Iraqi Dinar'), ('ILS', 'Israeli New Shekel'), ('JEP', 'JEP'), ('JMD', 'Jamaican Dollar'), ('JPY', 'Japanese Yen'), ('JOD', 'Jordanian Dinar'), ('KID', 'KID'), ('KZT', 'Kazakhstani Tenge'), ('KES', 'Kenyan Shilling'), ('KWD', 'Kuwaiti Dinar'), ('KGS', 'Kyrgystani Som'), ('LAK', 'Laotian Kip'), ('LBP', 'Lebanese Pound'), ('LSL', 'Lesotho Loti'), ('LRD', 'Liberian Dollar'), ('LYD', 'Libyan Dinar'), ('MOP', 'Macanese Pataca'), ('MKD', 'Macedonian Denar'), ('MGA', 'Malagasy Ariary'), ('MWK', 'Malawian Kwacha'), ('MYR', 'Malaysian Ringgit'), ('MVR', 'Maldivian Rufiyaa'), ('MRU', 'Mauritanian Ouguiya'), ('MUR', 'Mauritian Rupee'), ('MXN', 'Mexican Peso'), ('MDL', 'Moldovan Leu'), ('MNT', 'Mongolian Tugrik'), ('MAD', 'Moroccan Dirham'), ('MZN', 'Mozambican Metical'), ('MMK', 'Myanmar Kyat'), ('NAD', 'Namibian Dollar'), ('NPR', 'Nepalese Rupee'), ('ANG', 'Netherlands Antillean Guilder'), ('TWD', 'New Taiwan Dollar'), ('NZD', 'New Zealand Dollar'), ('NIO', 'Nicaraguan Córdoba'), ('NGN', 'Nigerian Naira'), ('KPW', 'North Korean Won'), ('NOK', 'Norwegian Krone'), ('OMR', 'Omani Rial'), ('PND', 'PND'), ('PRB', 'PRB'), ('PKR', 'Pakistani Rupee'), ('PAB', 'Panamanian Balboa'), ('PGK', 'Papua New Guinean Kina'), ('PYG', 'Paraguayan Guarani'), ('PEN', 'Peruvian Sol'), ('PHP', 'Philippine Piso'), ('PLN', 'Polish Zloty'), ('QAR', 'Qatari Rial'), ('RON', 'Romanian Leu'), ('RUB', 'Russian Ruble'), ('RWF', 'Rwandan Franc'), ('SLS', 'SLS'), ('WST', 'Samoan Tala'), ('SAR', 'Saudi Riyal'), ('RSD', 'Serbian Dinar'), ('SCR', 'Seychellois Rupee'), ('SLL', 'Sierra Leonean Leone'), ('SGD', 'Singapore Dollar'), ('SBD', 'Solomon Islands Dollar'), ('SOS', 'Somali Shilling'), ('ZAR', 'South African Rand'), ('KRW', 'South Korean Won'), ('SSP', 'South Sudanese Pound'), ('LKR', 'Sri Lankan Rupee'), ('SHP', 'St. Helena Pound'), ('SDG', 'Sudanese Pound'), ('SRD', 'Surinamese Dollar'), ('SZL', 'Swazi Lilangeni'), ('SEK', 'Swedish Krona'), ('CHF', 'Swiss Franc'), ('SYP', 'Syrian Pound'), ('STN', 'São Tomé & Príncipe Dobra'), ('TVD', 'TVD'), ('TJS', 'Tajikistani Somoni'), ('TZS', 'Tanzanian Shilling'), ('THB', 'Thai Baht'), ('TOP', 'Tongan Paʻanga'), ('TTD', 'Trinidad & Tobago Dollar'), ('TND', 'Tunisian Dinar'), ('TRY', 'Turkish Lira'), ('TMT', 'Turkmenistani Manat'), ('USD', 'US Dollar'), ('UGX', 'Ugandan Shilling'), ('UAH', 'Ukrainian Hryvnia'), ('AED', 'United Arab Emirates Dirham'), ('UYU', 'Uruguayan Peso'), ('UZS', 'Uzbekistani Som'), ('VUV', 'Vanuatu Vatu'), ('VES', 'Venezuelan Bolívar'), ('VND', 'Vietnamese Dong'), ('XOF', 'West African CFA Franc'), ('YER', 'Yemeni Rial'), ('ZWB', 'ZWB'), ('ZMW', 'Zambian Kwacha')], max_length=10)),
            ],
            options={
                'verbose_name': 'Product proxy (limit_choices_to)',
                'verbose_name_plural': 'Product proxies (limit_choices_to)',
                'db_table': 'product_product',
                'managed': False,
            },
        ),
        migrations.AlterModelOptions(
            name='product',
            options={'verbose_name': 'Product', 'verbose_name_plural': 'Products'},
        ),
    ]
