# Generated by Django 3.2.2 on 2021-05-11 23:45

from django.db import migrations, models
import valuta.contrib.django_integration.models
import valuta.currencies.amd
import valuta.currencies.eur


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('price', models.IntegerField()),
                ('currency', valuta.contrib.django_integration.models.CurrencyField(choices=[('AMD', valuta.currencies.amd.AMD), ('EUR', valuta.currencies.eur.EUR)], max_length=10)),
            ],
        ),
    ]
